=================
TestRail Reporter
=================
`Nosetests Plugin`_ to Report Test Results to `TestRail`_.

.. _`Nosetests Plugin`: https://nose.readthedocs.io/en/latest/
.. _`TestRail`: http://www.gurock.com/testrail/
